@@ -264,7 +264,7 @@ class MultiflipMCMCState(ABC):
 
         if psingle is None:
             psingle = self.g.num_vertices()
-        gibbs_sweeps = max(gibbs_sweeps, 1)
+        gibbs_sweeps = max((gibbs_sweeps, 1))
         nproposal = Vector_size_t(4)
         nacceptance = Vector_size_t(4)
         force_move = kwargs.pop("force_move", False)
@@ -407,7 +407,7 @@ class MultilevelMCMCState(ABC):
 
         if psingle is None:
             psingle = self.g.num_vertices()
-        merge_sweeps = max(merge_sweeps, 1)
+        merge_sweeps = max((merge_sweeps, 1))
         if M is None:
             M = self.g.num_vertices()
             global_moves = True
@@ -415,7 +415,7 @@ class MultilevelMCMCState(ABC):
             global_moves = False
         bclabel = self._get_bclabel()
         if bclabel is not None:
-            B_min = max(len(numpy.unique(bclabel.fa)), B_min)
+            B_min = max((len(numpy.unique(bclabel.fa)), B_min))
         if b_min is None:
             b_min = self.g.vertex_index.copy("int")
         if b_max is None:
@@ -706,9 +706,8 @@ class DrawBlockState(ABC):
         gradient = group_vector_property([gradient])
         b = self.g.own_property(self.b)
         return graph_tool.draw.graph_draw(self.g,
-                                          vertex_fill_color=kwargs.get("vertex_fill_color", b),
-                                          vertex_color=kwargs.get("vertex_color", b),
-                                          edge_gradient=kwargs.get("edge_gradient", gradient),
-                                          **dmask(kwargs, ["vertex_fill_color",
-                                                           "vertex_color",
-                                                           "edge_gradient"]))
+                                          vertex_fill_color=kwargs.pop("vertex_fill_color", b),
+                                          vertex_color=kwargs.pop("vertex_color", b),
+                                          edge_gradient=kwargs.pop("edge_gradient", gradient),
+                                          vcmap=kwargs.pop("vcmap", graph_tool.draw.default_cm),
+                                          **kwargs)
